#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: views.py 9754 2017-02-18 05:34:31Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-02-18 13:34:31 +0800 (?g??, 18 ?G?? 2017) $
# $Revision: 9754 $

import requests
import json

from django import template
from django.conf import settings
from django.utils.http import urlquote

register = template.Library()

def getApiData(url, fieldName):
    accessToken = '%s|%s' % (
        settings.SOCIAL_AUTH_FACEBOOK_KEY, 
        settings.SOCIAL_AUTH_FACEBOOK_SECRET
    )
    apiUrl = (
        'https://graph.facebook.com/v3.3/'
        '?id=%s&fields=engagement&access_token=%s' % (
        urlquote(url), accessToken)
    )
    data = json.loads(requests.get(apiUrl).text)
    if fieldName == "comment_count":
        # comment_plugin_count
        fieldName = "comment_plugin_count"
        return data.get("engagement", {}).get(fieldName, None)
    if fieldName == "share_count":
        # like
        fieldName = 'reaction_count'
        reaction = data.get("engagement", {}).get(fieldName, 0)
        fieldName = "comment_count"
        comment = data.get("engagement", {}).get(fieldName, 0)
        fieldName = 'share_count'
        share = data.get("engagement", {}).get(fieldName, 0)
        return reaction + share + comment
    return data.get("engagement", {}).get(fieldName, None)


@register.simple_tag(takes_context=True)
def likeCount(context, url=None):
    request = context['request']
    if url:
        if not url.startswith('http'): 
            url = request.build_absolute_uri('/')[:-1].strip("/") + url
    else:
        url = request.build_absolute_uri(request.path)

    count = getApiData(url, "share_count")
    
    if count:
        return count
    return 0